Django app with web forms to assist with the collection of data for Point-in-Time (PIT) counts
for the Annual Homeless Assessment Report (AHAR) sent to the U.S. Congress. You can view these
annual reports at: https://www.hudexchange.info/homelessness-assistance/ahar

Examples PDFs of the forms:
Intervew: https://files.hudexchange.info/resources/documents/Model-Interview-Based-Unsheltered-Night-of-Count-PIT-Survey.pdf
Observation: https://files.hudexchange.info/resources/documents/Model-Observation-Based-Unsheltered-Night-of-Count-PIT-Survey.pdf
